==> haskell-monad-journal-0.7.2-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.2
id: monad-journal-0.7.2-Kq0MX6OEWfqHhoNz5pe1zt
key: monad-journal-0.7.2-Kq0MX6OEWfqHhoNz5pe1zt
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: 31b9a41a11ff30fae80240586dc3b9e9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/monad-journal-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/monad-journal-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/monad-journal-0.7.2
hs-libraries: HSmonad-journal-0.7.2-Kq0MX6OEWfqHhoNz5pe1zt
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 transformers-0.5.2.0
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=9558fa760db7fa13c9efdaf91276757e
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.8.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.8.0
id: monad-journal-0.8.0-6oT7rCIn4Zt9GJx7MDddne
key: monad-journal-0.8.0-6oT7rCIn4Zt9GJx7MDddne
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: 019d6388db8c29674c48b3d8dff83238
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/monad-journal-0.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/monad-journal-0.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/monad-journal-0.8.0
hs-libraries: HSmonad-journal-0.8.0-6oT7rCIn4Zt9GJx7MDddne
depends:
    base-4.10.0.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 transformers-0.5.2.0
    either-4.5-LYT0d6MLKlX83NrOtw2Pp2
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             either-4.5-LYT0d6MLKlX83NrOtw2Pp2=7f1a11e1c3d8093dc62036c3f833d6de
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
